==> asap-2.1-3-x86_64.pkg.tar.zst: usr/lib/cmake/asap/cmake/asap-targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "core" for configuration ""
set_property(TARGET core APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(core PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libcore.so"
  IMPORTED_SONAME_NOCONFIG "libcore.so"
  )

list(APPEND _cmake_import_check_targets core )
list(APPEND _cmake_import_check_files_for_core "${_IMPORT_PREFIX}/lib/libcore.so" )

# Import target "multiresolutionimageinterface" for configuration ""
set_property(TARGET multiresolutionimageinterface APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(multiresolutionimageinterface PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "jpeg2kcodec"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libmultiresolutionimageinterface.so"
  IMPORTED_SONAME_NOCONFIG "libmultiresolutionimageinterface.so"
  )

list(APPEND _cmake_import_check_targets multiresolutionimageinterface )
list(APPEND _cmake_import_check_files_for_multiresolutionimageinterface "${_IMPORT_PREFIX}/lib/libmultiresolutionimageinterface.so" )

# Import target "jpeg2kcodec" for configuration ""
set_property(TARGET jpeg2kcodec APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(jpeg2kcodec PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "openjp2"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libjpeg2kcodec.so"
  IMPORTED_SONAME_NOCONFIG "libjpeg2kcodec.so"
  )

list(APPEND _cmake_import_check_targets jpeg2kcodec )
list(APPEND _cmake_import_check_files_for_jpeg2kcodec "${_IMPORT_PREFIX}/lib/libjpeg2kcodec.so" )

# Import target "openslidefileformat" for configuration ""
set_property(TARGET openslidefileformat APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(openslidefileformat PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "core"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/formats/libopenslidefileformat.so"
  IMPORTED_SONAME_NOCONFIG "libopenslidefileformat.so"
  )

list(APPEND _cmake_import_check_targets openslidefileformat )
list(APPEND _cmake_import_check_files_for_openslidefileformat "${_IMPORT_PREFIX}/bin/formats/libopenslidefileformat.so" )

# Import target "annotation" for configuration ""
set_property(TARGET annotation APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(annotation PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "multiresolutionimageinterface"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libannotation.so"
  IMPORTED_SONAME_NOCONFIG "libannotation.so"
  )

list(APPEND _cmake_import_check_targets annotation )
list(APPEND _cmake_import_check_files_for_annotation "${_IMPORT_PREFIX}/lib/libannotation.so" )

# Import target "basicfilters" for configuration ""
set_property(TARGET basicfilters APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(basicfilters PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libbasicfilters.so"
  IMPORTED_SONAME_NOCONFIG "libbasicfilters.so"
  )

list(APPEND _cmake_import_check_targets basicfilters )
list(APPEND _cmake_import_check_files_for_basicfilters "${_IMPORT_PREFIX}/lib/libbasicfilters.so" )

# Import target "FRST" for configuration ""
set_property(TARGET FRST APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(FRST PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "opencv_calib3d;opencv_core;opencv_dnn;opencv_features2d;opencv_flann;opencv_gapi;opencv_highgui;opencv_imgcodecs;opencv_imgproc;opencv_ml;opencv_objdetect;opencv_photo;opencv_stitching;opencv_video;opencv_videoio;opencv_alphamat;opencv_aruco;opencv_barcode;opencv_bgsegm;opencv_bioinspired;opencv_ccalib;opencv_cvv;opencv_datasets;opencv_dnn_objdetect;opencv_dnn_superres;opencv_dpm;opencv_face;opencv_freetype;opencv_fuzzy;opencv_hdf;opencv_hfs;opencv_img_hash;opencv_intensity_transform;opencv_line_descriptor;opencv_mcc;opencv_optflow;opencv_phase_unwrapping;opencv_plot;opencv_quality;opencv_rapid;opencv_reg;opencv_rgbd;opencv_saliency;opencv_shape;opencv_stereo;opencv_structured_light;opencv_superres;opencv_surface_matching;opencv_text;opencv_tracking;opencv_videostab;opencv_viz;opencv_wechat_qrcode;opencv_xfeatures2d;opencv_ximgproc;opencv_xobjdetect;opencv_xphoto"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libFRST.so"
  IMPORTED_SONAME_NOCONFIG "libFRST.so"
  )

list(APPEND _cmake_import_check_targets FRST )
list(APPEND _cmake_import_check_files_for_FRST "${_IMPORT_PREFIX}/lib/libFRST.so" )

# Import target "wholeslidefilters" for configuration ""
set_property(TARGET wholeslidefilters APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(wholeslidefilters PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "opencv_calib3d;opencv_core;opencv_dnn;opencv_features2d;opencv_flann;opencv_gapi;opencv_highgui;opencv_imgcodecs;opencv_imgproc;opencv_ml;opencv_objdetect;opencv_photo;opencv_stitching;opencv_video;opencv_videoio;opencv_alphamat;opencv_aruco;opencv_barcode;opencv_bgsegm;opencv_bioinspired;opencv_ccalib;opencv_cvv;opencv_datasets;opencv_dnn_objdetect;opencv_dnn_superres;opencv_dpm;opencv_face;opencv_freetype;opencv_fuzzy;opencv_hdf;opencv_hfs;opencv_img_hash;opencv_intensity_transform;opencv_line_descriptor;opencv_mcc;opencv_optflow;opencv_phase_unwrapping;opencv_plot;opencv_quality;opencv_rapid;opencv_reg;opencv_rgbd;opencv_saliency;opencv_shape;opencv_stereo;opencv_structured_light;opencv_superres;opencv_surface_matching;opencv_text;opencv_tracking;opencv_videostab;opencv_viz;opencv_wechat_qrcode;opencv_xfeatures2d;opencv_ximgproc;opencv_xobjdetect;opencv_xphoto;annotation;FRST;basicfilters;multiresolutionimageinterface"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libwholeslidefilters.so"
  IMPORTED_SONAME_NOCONFIG "libwholeslidefilters.so"
  )

list(APPEND _cmake_import_check_targets wholeslidefilters )
list(APPEND _cmake_import_check_files_for_wholeslidefilters "${_IMPORT_PREFIX}/lib/libwholeslidefilters.so" )

# Import target "py_wholeslidefilters" for configuration ""
set_property(TARGET py_wholeslidefilters APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(py_wholeslidefilters PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NOCONFIG ""
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/_wholeslidefilters.so"
  IMPORTED_NO_SONAME_NOCONFIG "TRUE"
  )

list(APPEND _cmake_import_check_targets py_wholeslidefilters )
list(APPEND _cmake_import_check_files_for_py_wholeslidefilters "${_IMPORT_PREFIX}/bin/_wholeslidefilters.so" )

# Import target "ASAP" for configuration ""
set_property(TARGET ASAP APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ASAP PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/ASAP"
  )

list(APPEND _cmake_import_check_targets ASAP )
list(APPEND _cmake_import_check_files_for_ASAP "${_IMPORT_PREFIX}/bin/ASAP" )

# Import target "ASAPLib" for configuration ""
set_property(TARGET ASAPLib APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ASAPLib PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "multiresolutionimageinterface;Qt5::Widgets;Qt5::Core;Qt5::OpenGL"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libASAPLib.so"
  IMPORTED_SONAME_NOCONFIG "libASAPLib.so"
  )

list(APPEND _cmake_import_check_targets ASAPLib )
list(APPEND _cmake_import_check_files_for_ASAPLib "${_IMPORT_PREFIX}/lib/libASAPLib.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> asap-2.1-4-x86_64.pkg.tar.zst: usr/lib/cmake/asap/cmake/asap-targets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "core" for configuration ""
set_property(TARGET core APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(core PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libcore.so"
  IMPORTED_SONAME_NOCONFIG "libcore.so"
  )

list(APPEND _cmake_import_check_targets core )
list(APPEND _cmake_import_check_files_for_core "${_IMPORT_PREFIX}/lib/libcore.so" )

# Import target "py_multiresolutionimageinterface" for configuration ""
set_property(TARGET py_multiresolutionimageinterface APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(py_multiresolutionimageinterface PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NOCONFIG ""
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/_multiresolutionimageinterface.so"
  IMPORTED_NO_SONAME_NOCONFIG "TRUE"
  )

list(APPEND _cmake_import_check_targets py_multiresolutionimageinterface )
list(APPEND _cmake_import_check_files_for_py_multiresolutionimageinterface "${_IMPORT_PREFIX}/bin/_multiresolutionimageinterface.so" )

# Import target "multiresolutionimageinterface" for configuration ""
set_property(TARGET multiresolutionimageinterface APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(multiresolutionimageinterface PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "jpeg2kcodec"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libmultiresolutionimageinterface.so"
  IMPORTED_SONAME_NOCONFIG "libmultiresolutionimageinterface.so"
  )

list(APPEND _cmake_import_check_targets multiresolutionimageinterface )
list(APPEND _cmake_import_check_files_for_multiresolutionimageinterface "${_IMPORT_PREFIX}/lib/libmultiresolutionimageinterface.so" )

# Import target "jpeg2kcodec" for configuration ""
set_property(TARGET jpeg2kcodec APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(jpeg2kcodec PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "openjp2"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libjpeg2kcodec.so"
  IMPORTED_SONAME_NOCONFIG "libjpeg2kcodec.so"
  )

list(APPEND _cmake_import_check_targets jpeg2kcodec )
list(APPEND _cmake_import_check_files_for_jpeg2kcodec "${_IMPORT_PREFIX}/lib/libjpeg2kcodec.so" )

# Import target "openslidefileformat" for configuration ""
set_property(TARGET openslidefileformat APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(openslidefileformat PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "core"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/formats/libopenslidefileformat.so"
  IMPORTED_SONAME_NOCONFIG "libopenslidefileformat.so"
  )

list(APPEND _cmake_import_check_targets openslidefileformat )
list(APPEND _cmake_import_check_files_for_openslidefileformat "${_IMPORT_PREFIX}/bin/formats/libopenslidefileformat.so" )

# Import target "annotation" for configuration ""
set_property(TARGET annotation APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(annotation PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "multiresolutionimageinterface"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libannotation.so"
  IMPORTED_SONAME_NOCONFIG "libannotation.so"
  )

list(APPEND _cmake_import_check_targets annotation )
list(APPEND _cmake_import_check_files_for_annotation "${_IMPORT_PREFIX}/lib/libannotation.so" )

# Import target "basicfilters" for configuration ""
set_property(TARGET basicfilters APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(basicfilters PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libbasicfilters.so"
  IMPORTED_SONAME_NOCONFIG "libbasicfilters.so"
  )

list(APPEND _cmake_import_check_targets basicfilters )
list(APPEND _cmake_import_check_files_for_basicfilters "${_IMPORT_PREFIX}/lib/libbasicfilters.so" )

# Import target "FRST" for configuration ""
set_property(TARGET FRST APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(FRST PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "opencv_calib3d;opencv_core;opencv_dnn;opencv_features2d;opencv_flann;opencv_gapi;opencv_highgui;opencv_imgcodecs;opencv_imgproc;opencv_ml;opencv_objdetect;opencv_photo;opencv_stitching;opencv_video;opencv_videoio;opencv_alphamat;opencv_aruco;opencv_bgsegm;opencv_bioinspired;opencv_ccalib;opencv_cvv;opencv_datasets;opencv_dnn_objdetect;opencv_dnn_superres;opencv_dpm;opencv_face;opencv_freetype;opencv_fuzzy;opencv_hdf;opencv_hfs;opencv_img_hash;opencv_intensity_transform;opencv_line_descriptor;opencv_mcc;opencv_optflow;opencv_phase_unwrapping;opencv_plot;opencv_quality;opencv_rapid;opencv_reg;opencv_rgbd;opencv_saliency;opencv_shape;opencv_stereo;opencv_structured_light;opencv_superres;opencv_surface_matching;opencv_text;opencv_tracking;opencv_videostab;opencv_viz;opencv_wechat_qrcode;opencv_xfeatures2d;opencv_ximgproc;opencv_xobjdetect;opencv_xphoto"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libFRST.so"
  IMPORTED_SONAME_NOCONFIG "libFRST.so"
  )

list(APPEND _cmake_import_check_targets FRST )
list(APPEND _cmake_import_check_files_for_FRST "${_IMPORT_PREFIX}/lib/libFRST.so" )

# Import target "wholeslidefilters" for configuration ""
set_property(TARGET wholeslidefilters APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(wholeslidefilters PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "opencv_calib3d;opencv_core;opencv_dnn;opencv_features2d;opencv_flann;opencv_gapi;opencv_highgui;opencv_imgcodecs;opencv_imgproc;opencv_ml;opencv_objdetect;opencv_photo;opencv_stitching;opencv_video;opencv_videoio;opencv_alphamat;opencv_aruco;opencv_bgsegm;opencv_bioinspired;opencv_ccalib;opencv_cvv;opencv_datasets;opencv_dnn_objdetect;opencv_dnn_superres;opencv_dpm;opencv_face;opencv_freetype;opencv_fuzzy;opencv_hdf;opencv_hfs;opencv_img_hash;opencv_intensity_transform;opencv_line_descriptor;opencv_mcc;opencv_optflow;opencv_phase_unwrapping;opencv_plot;opencv_quality;opencv_rapid;opencv_reg;opencv_rgbd;opencv_saliency;opencv_shape;opencv_stereo;opencv_structured_light;opencv_superres;opencv_surface_matching;opencv_text;opencv_tracking;opencv_videostab;opencv_viz;opencv_wechat_qrcode;opencv_xfeatures2d;opencv_ximgproc;opencv_xobjdetect;opencv_xphoto;annotation;FRST;basicfilters;multiresolutionimageinterface"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libwholeslidefilters.so"
  IMPORTED_SONAME_NOCONFIG "libwholeslidefilters.so"
  )

list(APPEND _cmake_import_check_targets wholeslidefilters )
list(APPEND _cmake_import_check_files_for_wholeslidefilters "${_IMPORT_PREFIX}/lib/libwholeslidefilters.so" )

# Import target "py_wholeslidefilters" for configuration ""
set_property(TARGET py_wholeslidefilters APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(py_wholeslidefilters PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_NOCONFIG ""
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/_wholeslidefilters.so"
  IMPORTED_NO_SONAME_NOCONFIG "TRUE"
  )

list(APPEND _cmake_import_check_targets py_wholeslidefilters )
list(APPEND _cmake_import_check_files_for_py_wholeslidefilters "${_IMPORT_PREFIX}/bin/_wholeslidefilters.so" )

# Import target "ASAP" for configuration ""
set_property(TARGET ASAP APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ASAP PROPERTIES
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/bin/ASAP"
  )

list(APPEND _cmake_import_check_targets ASAP )
list(APPEND _cmake_import_check_files_for_ASAP "${_IMPORT_PREFIX}/bin/ASAP" )

# Import target "ASAPLib" for configuration ""
set_property(TARGET ASAPLib APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(ASAPLib PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "multiresolutionimageinterface;Qt5::Widgets;Qt5::Core;Qt5::OpenGL"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libASAPLib.so"
  IMPORTED_SONAME_NOCONFIG "libASAPLib.so"
  )

list(APPEND _cmake_import_check_targets ASAPLib )
list(APPEND _cmake_import_check_files_for_ASAPLib "${_IMPORT_PREFIX}/lib/libASAPLib.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
